# spec file for package bitwarden
#
#
# Copyright (c) 2023 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2021–2023 Bruno Pitrus
# Based on the Arch Linux PKGBUILD (c) 2017 prozum
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

#not running the tests on OBS — extremely flaky
%bcond_with test_rust


Name:       bitwarden
Version:    2024.11.0
Release:    1.1
Summary:    A secure and free password manager for all of your devices
Group:      Productivity/Security
License:    GPL-3.0-only and MIT and (Apache-2.0 or MIT)
URL:        https://github.com/bitwarden/clients

#x86 electron requires SSE2
%ifarch %ix86
ExclusiveArch:  i586 i686
BuildArch:      i686
%{expand:%%global optflags %(echo "%optflags") -march=pentium4 -mtune=generic}
%{expand:%%global build_rustflags %(echo "%build_rustflags") -C target-cpu=pentium4 -Z tune-cpu=generic}
%endif

%define version_suffix desktop

# created by OBS service
Source0:   bitwarden-%{version}.tar

# created by prepare-vendor.sh
Source1:   vendor.tar.zst

Source2:   bitwarden.sh
Source3:   bitwarden.desktop

Source99:  prepare-vendor.sh



#openSUSE-specific patches
Patch0:    remove-unnecessary-deps.patch
Patch1:    fix-desktop-file.patch
Patch3:    do-not-install-font-privately.patch
Patch4:    desktop_native-rust-arch.patch
Patch5:    remove-argon2-browser.patch
Patch7:    bug-reporting-url.patch
Patch8:    no-sourcemaps.patch
Patch9:    main-getPath-exe.patch
Patch10:   native-messaging.main-fix-path.patch

#patches to remove stuff we do not want
Patch500:  remove-sdk-internal.patch

#patches to use system libs
Patch1000: system-libargon2.patch

#patches to fix upstream hostility (DRM etc.)
Patch4000: remove-esbuild-version-check.patch

#tools we use explicitly
%if 0%{?fedora_version}
%define _ttfontsdir %{_datadir}/fonts/truetype
BuildRequires: glibc-all-langpacks
%endif
%if 0%{?fedora} >= 37
BuildRequires:  nodejs-npm
%else
BuildRequires:  npm
%endif
BuildRequires: cargo
%if 0%{?fedora}
BuildRequires:  rust-srpm-macros
%else
BuildRequires:  cargo-packaging >= 1.2.0+3
BuildRequires:  cargo-auditable
%endif
BuildRequires: fdupes
BuildRequires: fontpackages-devel
BuildRequires: hicolor-icon-theme
BuildRequires: jq
%if 0%{?suse_version}
BuildRequires: nodejs-packaging
%endif
BuildRequires: nodejs-electron-devel
BuildRequires: pkgconfig(libargon2)
BuildRequires: sed
BuildRequires: zstd
#Tools used by npm
BuildRequires: gcc-c++
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(libsecret-1)
BuildRequires: pkgconfig(wayland-protocols)

#For tests
%if %{with test_rust}
BuildRequires:  gnome-keyring
%if 0%{?fedora}
BuildRequires:  dbus-daemon
%else
BuildRequires:  dbus-1-daemon
%endif
%endif

Requires: (google-opensans-fonts or open-sans-fonts)
Requires: nodejs-electron%{_isa}

%global __requires_exclude ^npm(.*)|^nodejs(.*)
%global __provides_exclude ^npm(.*)|^nodejs(.*)|^lib.*\\.so.*$



%description
Bitwarden is a free and open-source password management service that stores sensitive information such as website credentials in an encrypted vault.  Bitwarden offers a cloud-hosted service as well as the ability to deploy the solution on-premises. This package provides the GUI client.

%prep
%autosetup -p1 -a1

#fix exe path
sed -i 's[XXXLIBDIRXXX[%{_libdir}[g' apps/desktop/src/main/native-messaging.main.ts


# Remove unused postinstall script (electron-rebuild)
sed -i '/"postinstall":/d' apps/desktop/package.json

#Remove bundled open sans
cp -v /dev/null libs/angular/src/scss/webfonts.css
rm -rvf libs/angular/src/scss/webfonts




#Do not install font privately

mv -v libs/angular/src/scss/bwicons/fonts/bwi-font.woff %{_builddir}
rm -rvf libs/angular/src/scss/bwicons/fonts


#Rust config
cd apps/desktop/desktop_native
rm -rf vendor/wayland-protocols/protocols
ln -svT /usr/share/wayland-protocols vendor/wayland-protocols/protocols
# https://blogs.gnome.org/mcatanzaro/2020/05/18/patching-vendored-rust-dependencies/
for i in wayland-protocols libloading system-deps; do
pushd vendor/$i
jq -cj '.files={}' .cargo-checksum.json >tmp && mv tmp .cargo-checksum.json && popd
done



%build
%ifarch %ix86
export RUSTC_BOOTSTRAP=1
%endif
export RUSTC_LOG='rustc_codegen_ssa::back::link=info'
export RUSTFLAGS="%{build_rustflags} --verbose -Cstrip=none"
export CARGO_TERM_VERBOSE=true

export ELECTRON_SKIP_BINARY_DOWNLOAD=1

#esbuild is not actually used, it is only declared as a dependency of some webpack plugin
export ESBUILD_BINARY_PATH=/bin/true


export CFLAGS="%{optflags} -fpic -fno-semantic-interposition -fvisibility=hidden"
export CXXFLAGS="%{optflags} -fpic -fno-semantic-interposition -fvisibility=hidden"
export LDFLAGS="%{?build_ldflags}"
export MAKEFLAGS="%{_smp_mflags}"

%if 0%{?suse_version}
auditable='auditable -vv'
%endif




%electron_rebuild

cd apps/desktop
pushd desktop_native
cargo -vv $auditable rustc --offline --release --package desktop_napi --lib --crate-type cdylib
RUSTFLAGS="$RUSTFLAGS -Crelocation-model=pie" cargo -vv $auditable rustc --offline --release --package desktop_proxy --bin desktop_proxy
popd

npm run build
npm run clean:dist

#copy this manually instead of using electron-builder. there's few enough dependencies.
cd build
mkdir -pv node_modules/@bitwarden/desktop-napi
cp -plv ../desktop_native/napi/{package.json,index.js} -t node_modules/@bitwarden/desktop-napi
cp -plvT ../desktop_native/target/release/*.so node_modules/@bitwarden/desktop-napi/desktop_napi.node
cp -plv -t . ../desktop_native/target/release/desktop_proxy
rm -fv ../../../node_modules/argon2/build-tmp-napi-v3/node_gyp_bins/python3
cp -plvr ../../../node_modules/argon2 -t node_modules/
cp -plvr ../../../node_modules/node-gyp-build -t node_modules/
cp -plvr '../../../node_modules/@phc' -t node_modules/


%install
cd %{_builddir}/bitwarden-%{version}/apps/desktop
mkdir -pv %{buildroot}%{_libdir}
cp -ar build %{buildroot}%{_libdir}/%{name}
for i in 16 32 64 128 256 512 1024
do
install -pvDm644 resources/icons/${i}x${i}.png "%{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png"
done
install -pvDm755 "%{_sourcedir}/%{name}.sh" "%{buildroot}%{_bindir}/bitwarden-desktop"
sed -i "s,XXXLIBDIRXXX,%{_libdir},g" "%{buildroot}%{_bindir}/bitwarden-desktop"
install -pvDm644 "%{_sourcedir}"/%{name}.desktop -t "%{buildroot}%{_datadir}"/applications
install -pvDm644 %{_builddir}/bwi-font.woff -t%{buildroot}%{_ttfontsdir}

%fdupes %{buildroot}%{_prefix}

#Remove development garbage
cd %{buildroot}%{_libdir}/%{name}
#JS debug symbols (unusable)
find -name '*.map' -type f -print -delete
#Source code
find -name '*.c' -type f -print -delete
find -name '*.cpp' -type f -print -delete
find -name '*.h' -type f -print -delete
find -name '*.gyp' -type f -print -delete
find -name '*.gypi' -type f -print -delete
find -name '*.ts' -type f -print -delete
find -name '*.cts' -type f -print -delete
find -name build-tmp-napi-v3  -print0 |xargs -r0 -- rm -rvf --
find -name src -print0 |xargs -r0 -- rm -rvf --
find -name Makefile -type f -print -delete
find -name 'Pipfile*' -type f -print -delete
find -name '*.patch' -type f -print -delete
#Temporary build files
find -name '.deps' -print0 |xargs -r0 -- rm -rvf --
find -name 'obj.target' -print0 |xargs -r0 -- rm -rvf --
find -name 'vendor' -print0 |xargs -r0 -- rm -rvf --
find -name '*package-lock.json' -type f -print -delete
find -name '*.mk' -type f -print -delete
find -name '*.Makefile' -type f -print -delete

#Documentation
find -name '*.md' -type f -print -delete
find -name doc -print0 |xargs -r0 -- rm -rvf --
find -name test -print0 |xargs -r0 -- rm -rvf --
#Compile-time-only dependencies
find -name nan -print0 |xargs -r0 -- rm -rvf --
find -name node-addon-api -print0 |xargs -r0 -- rm -rvf --
#Other trash
find -name '*.yml' -type f -print -delete
find -name '.npmignore' -type f -print -delete
find -name '.gitignore' -type f -print -delete

#Fix file mode
find . -type f -exec chmod 644 {} \;
find . -name '*.node' -exec chmod 755 {} \;
chmod 755 desktop_proxy

# Remove empty directories
find . -type d -empty -print -delete


%if 0%{?suse_version}
%reconfigure_fonts_scriptlets
%endif

%check
%electron_check_native

#Rust tests
%if %{with test_rust}
%ifarch %ix86
export RUSTC_BOOTSTRAP=1
%endif
export RUSTC_LOG='rustc_codegen_ssa::back::link=info'
export RUSTFLAGS="%{build_rustflags} --verbose -Cstrip=none"
export CARGO_TERM_VERBOSE=true
export CFLAGS="%{optflags} -fpic -fno-semantic-interposition -fvisibility=hidden"
export CXXFLAGS="%{optflags} -fpic -fno-semantic-interposition -fvisibility=hidden"
export LDFLAGS="%{?build_ldflags}"
export MAKEFLAGS="%{_smp_mflags}"
%if 0%{?suse_version}
auditable='auditable -vv'
%endif
cd apps/desktop
pushd desktop_native
# see .github/workflows/test.yml
export XDG_CONFIG_HOME=$(mktemp -d)

dbus-run-session sh -c ' echo '' | gnome-keyring-daemon --unlock && echo '' | gnome-keyring-daemon --start && exec cargo -vv '"$auditable"' test --release --no-fail-fast --workspace -- --test-threads=1'
%endif

%files
%defattr(-,root,root)
%{_bindir}/bitwarden-desktop
%{_libdir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/1024x1024
%{_datadir}/icons/hicolor/128x128/apps/bitwarden.png
%{_datadir}/icons/hicolor/16x16/apps/bitwarden.png
%{_datadir}/icons/hicolor/256x256/apps/bitwarden.png
%{_datadir}/icons/hicolor/32x32/apps/bitwarden.png
%{_datadir}/icons/hicolor/512x512/apps/bitwarden.png
%{_datadir}/icons/hicolor/64x64/apps/bitwarden.png
%{_ttfontsdir}/
%license LICENSE.txt
%license LICENSE_GPL.txt

%changelog
* Fri Nov 15 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.11.0
  * Security update for generating passphrases
  * Enable email verification for account creation
* Fri Oct 25 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.10.0
  * no changelog provided
- Add native-messaging.main-fix-path.patch
- Remove a temporarily-nonfree new dependency that is currently dead code (gh#bitwarden/clients#11611)
  * add remove-sdk-internal.patch
* Thu Sep 19 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.9.0
  * no changelog provided
* Thu Sep 12 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- Fix exe path in mozilla manifest (bsc#1230388)
  * add main-getPath-exe.patch
- Remove bogus libdesktop_napi.so provide
* Thu Sep  5 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.8.2
  * Disable cipher key encryption due to problems (gh#bitwarden/clients#10621)
* Wed Aug 28 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.8.1
  * no changelog provided
* Sun Aug 25 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.8.0
  * Allow biometric unlock of browser extension without requiring desktop app to be unlocked
  * Add support for users to set a master password when their organization updates member decryption options
  * Added support for multi-thread encryption to improve performance
  * Add support for biometric unlock on Linux
  * Add support for vault timeout on system lock on Linux
* Fri Jul 26 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.7.1
  * Enable individual vault item encryption keys 🔑
* Mon Jul 15 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.7.0
  * Deprecated setting for approving logins. Desktop now receives login requests by default.
- Drop no longer needed argon2-binary-path.patch
* Wed Jun 19 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.6.2
  * no user-visible changes
* Wed Jun 12 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.6.0
  * Added password protected export
  * Fixed issue with email alias provider keys being stored in plaintext
* Tue May 21 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.5.0
  * no changelog provided
- Use new %%electron_rebuild and %%electron_check_native macros in specfile
* Mon May  6 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.4.3
  * no changelog provided
* Mon Apr  8 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.3.2
  * no changelog provided
- Remove non-Linux stuff from rust vendor tarball
- Work around missing debuginfo (bsc#1222175)
* Fri Mar  8 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.2.1
  * Fix issues with clipboard under Wayland
- Drop half of use-node-argon2.patch which was applied upstream and rename the rest as remove-argon2-browser.patch
* Wed Feb  7 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.2.0
  * Increased import item quantity maximum
* Wed Jan 10 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2024.1.0
  * Added password complexity checks to password protected export
  * Disallow XXE in import
  * Bug-fixes for imports
  * Bug-fix for minimum/maximum values in generator
  * Bug-fix for screen-readers not announcing stored passkeys
* Thu Dec 21 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.12.1
  * Make autofill overlay off by default
* Wed Dec  6 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.12.0
  * Add prompt to set master password when user logs in with new permissions
  * Add support for Azure AD to LastPass direct import
  * Modify switch account dropdown/dialog for accessibility
* Mon Nov 27 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Fix FTBFS with npm21
* Tue Nov  7 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.10.1
  * no user-visible changes
* Wed Nov  1 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.10.0
  * View and edit login items with passkeys saved to them
  * Add import functionality
  * Add direct import for LastPass
  * Add support for self-hosting email alias generators
  * Bug fix for Duo hardware keys
* Thu Oct 12 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.9.2
  * Individual Vault Item Encryption Feature
* Thu Sep 21 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.9.0
  * Added password history to Bitwarden export
  * Accessibility improvement for fingerprint-phrases
  * Update dark theme to match web app
  * Update AnonAddy to addy.io
  * Remove flags from environment selector
  * Security fixes
  * Bug-fix for password re-prompt
  * Bug-fix for Duo prompt
* Wed Sep  6 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.8.3
  * Support onboarding Key Connector users with existing master passwords
  * Handle user decryption options from pre-TDE server response
* Mon Aug 28 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.8.2
  * Add SSO with trusted devices
  * Add Tailwind support
  * Update server selector copy
  * Bug fix for selecting self-hosted server
  * Bug fix for hidden icons
* Wed Jul 26 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.7.1
  * Remove sensitive data from memory when reloading the application
* Sun Jul 23 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.7.0
  * Login with device enabled for self-host
  * Added new forwarder (Forward Email)
  * Add collection name to title attribute
  * Define card brand according to its number
* Thu Jun 22 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.5.1
  * Fix bug when the user selects a region it will set baseUrl in environment service
- Revert build_rustflags hack (boo#1212226)
* Mon Jun 12 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Replace deprecated rust-packaging with cargo-packaging (boo#1211624)
- Fix unresolvable build on Fedora
* Wed May 31 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.5.0
  * Updated interface for selecting self-hosted environment
- Add SingleMainWindow to .desktop file.
* Wed Apr 26 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.4.0
  * Send service refactor
  * Updated help links
- Correct bogus npm(…) RPM provides
- Do not ship JS debuginfo (no-sourcemaps.patch)
- Fix unresolvable build on Fedora
* Fri Apr  7 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.3.2
  * Copy send link fix
* Tue Mar 28 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.3.1
  * Fix Vault Items with null Folder Value not Handled Correctly
* Wed Mar 22 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.3.0
  * Restyle generator panel to be panel-like and avoid overflowing
- Use obs-scm service for downloading clean tarball and package node vendor separately.
* Sat Feb 18 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Remove use of local-npm-proxy and cleanup tarball from prebuilt blobs
  * remove-esbuild-version-check.patch
- Replace argon2-browser which was not built from source with node-argon2
  * use-node-argon2.patch
  * argon2-binary-path.patch
  * system-libargon2.patch
- Do not use napi-rs, instead run cargo manually.
  * this gets us past the current build error on riscv, but there are further problems
- Use electron-node for building again as we ship a C module now (still ABI-stable tho)
- Replace bug reporting menu option with a link to openSUSE's bugzilla.
  * bug-reporting-url.patch
* Fri Feb 17 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.2.0
  * Expand passwordless login support to desktop and add login with device option
  * Add login request notifications
  * When creating a master password at account creation, users will now be able to check if their selected master password has been in any data breeches via the Have I Been Pwned? API
  * Expand title with “Mx“ option on an identity item
  * Bug fix for cloning organizational items
* Wed Jan 11 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2023.1.0
  * Bug fix for password generator not updating after settings change
  * Re-order settings for browser integrations
  * Change forwarded email providers to dropdown
  * Add hidden password character count toggle to item modal
  * Manage zoom factor when opening / closing the application
  * Tweak disclosure widget design
  * Accessibility: tweak left-hand filters
  * Fix inconsistent line height in cipher box footer
  * Accessibility: Make username regenerator button same as password one
- Do not Require: electron(abi), as the Rust plugin
  only uses stable ABIs and its build process does not even look at Electron headers.
* Wed Jan  4 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Fix npm crash causing broken RPMs (missing files) getting built
- Correct wrong cpu tuning for rust code on ix86
- Remove hardcoded list of architectures from desktop_native-rust-arch.patch
* Wed Dec 14 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2022.12.0
  * no changelog given by upstream
* Tue Nov 29 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2022.11.0
  * Updated login flow that splits username and master password into separate pages
  * Updated styles for selects and form groups for accessibility
  * Add folder to item view
  * explicitly define themed text ::selection styles
  * Add Duckduckgo’s email forwarding service
  * Display creation date in vault item history
* Mon Oct 24 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2022.10.1
  * Correct a visual bug involving truncation of ciphers.
* Thu Oct 13 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- New upstream release 2022.10.0
  * DuckDuckGo browser integration
  * Added DuckDuckGo to forwarded email providers list
  * Updated error message for missing master password
  * Enable Arabic support
  * Make all item fields (except linked fields) draggable
  * Don’t prevent whitespace wrapping in links/buttons, widen desktop pages
* Mon Oct  3 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Fix unsatisfiable requirment on Fedora
* Thu Sep 15 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 2022.9.1
- New upstream release 2022.9.1
  * no user-visible changes
* Wed Sep  7 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 2022.9.0
- New upstream release 2022.9.0
  * Major rewrite of the application in Rust.
* Fri Aug 12 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 2022.8.1
- New upstream release 2022.8.1
  * Add ability to delete user account
- New upstream release 2022.8.0
  * Names and descriptions of some app settings and preferences have been updated to be more intuitive.
  * Updates to Captcha styling
  * Suppress user-select for most interface elements
  * Bug fix to allow search with one letter
- Use electron instead of node to run NPM to fix build on Rawhide
* Tue Jul 12 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 2022.6.2
- New upstream release 2022.6.2
  * No user-visible changes
* Wed Jun 29 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 2022.6.0
- New upstream release 2022.6.0
  * Vault timeout fix that requires a minimum of 1 min lockout
* Sat Jun  4 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Do not use electron-builder, instead install dependencies manually
- Replace remove-postinstallscript.patch with more comprehensive remove-unnecessary-deps.patch to trim down unnecessary vendored deps
* Thu Jun  2 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 2022.05.0
- New upstream URL and changed tarball structure (upstream migrated to monorepo)
- New upstream release
  * no changelog provided
- Remove patches applied upstream
  * Fix-incompatible-keytar-versions.patch
  * Security-upgrade-keytar.patch
- Regenerate package-lock.json
  * async: 0.9.2 -> 3.2.3
  * caniuse-lite: 1.0.30001325 -> 1.0.30001327
  * ejs: 3.1.6 -> 3.1.7
  * filelist: 1.0.2 -> 1.0.3
  * jake: 10.8.4 -> 10.8.5
  * keytar: 7.8.0 -> 7.9.0
  * Added deps: brace-expansion 2.0.1, minimatch 5.0.1
  * Lots of removed deps
* Sun May 29 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Remove spurious `prebuild-install` copy and other dev files from the package.
* Mon May  2 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- [LEGAL] Do not use vendored app-builder binary which has no corresponding source
- Patch electron-rebuild to remove unused lzma-native dependency
* Mon Apr 25 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.33.0
- New upstream release
  * Accessibility update on “Generator” to announce slider element when clicked with assistive technologies
- Update jslib
- Regenerate package-lock.json
  * too many changes to list
* Fri Apr  8 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Remove remove-windows-security-credentials.patch and replace it with a proper fix
* Thu Apr  7 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Use woff font instead of woff2 because woff2 support removed in Electron 18
- Mark package as binary compatible with Electron 17.0 – 18.x
* Thu Mar 17 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Disallow installing on earlier electron version than the one the RPM was built with.
* Wed Mar 16 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.32.0
- New upstream release
  * Introduce captcha upon 5 failed login attempts
- Update jslib
- Regenerate package-lock.json
  * tslint has been replaced by eslint
* Tue Feb 15 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.31.3
- New upstream release
  * No user visible changes.
- Update jslib
- Regenerate package-lock.json:
  * keytar/node_modules/detect-libc 2.0.0 -> 2.0.1
- Add URL scheme handler to desktop file to follow upstream packages.
* Sun Feb 13 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.31.2
- Add Security-upgrade-keytar.patch
  * SNYK-JS-SIMPLEGET-2361683 / CVE-2022-0355
    Exposure of Sensitive Information to an Unauthorized Actor in NPM simple-get prior to 4.0.1.
- Add Fix-incompatible-keytar-versions.patch because snyk bot is stupid
- Regenerate package-lock.json:
  * keytar                               7.7.0  -> 7.8.0
  * keytar/node_modules/detect-libc      (none) -> 2.0.0
  * keytar/node_modules/node_abi         2.30.1 -> (none)
  * keytar/node_modules/node_addon_api   3.2.1  -> 4.3.0
  * keytar/node_modules/prebuild-install 6.1.4  -> 7.0.1
  * keytar/node_modules/semver           5.7.1  -> (none)
  * keytar/node_modules/simple-get       (none) -> 4.0.1
* Sat Feb 12 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.31.2
- New upstream release
  * No user visible changes.
- Update jslib
* Fri Feb 11 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.31.1
- New upstream release
  * No user visible changes.
- Update jslib
- Regenerate package-lock.json
  * No changes in dependencies.
* Fri Feb 11 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.31.0
- New upstream release
  * Account switching!
  * Icon updates
  * UX improvements
  * Various security and bug fixes
- Update jslib
- Remove patches applied upstream:
  * bump-node-to-16.patch
  * bump-node-to-16-jslib.patch
- Adjust patches to upstream changes:
  * fix-desktop-file.patch
  * remove-windows-security-credentials.patch
- Remove patch which no longer applies:
  * remove-bundled-fontawesome.patch
- Remove dependency on fontawesome (not used anymore)
- Add do-not-install-font-privately.patch
- Regenerate package-lock.json
  * Too many changes to list, mainly because upstream bumped recommended Node and Electron versions.
* Fri Jan 28 2022 Bruno Pitrus <brunopitrus@hotmail.com> - 1.30.0
- Clean up spec file
- Adjust bump-node-to-16.patch to more closely match upstream and avoid dependency mismatch
- Use nodejs-electron-devel instead of providing vendored headers
- Regenerate package-lock.json:
  * @types/node                                       16.11.17 -> 16.11.21
  * jslib/{common,electron}/node_modules/@types/node  14.18.2  -> (none)
  * electron/node_modules/@types/node                 14.18.2  -> 14.18.9
  * @nodert-win10-rs4/windows.security.credentials.ui 0.4.4    -> (none)
* Tue Dec 28 2021 Bruno Pitrus <brunopitrus@hotmail.com> - 1.30.0
- Initial version
- Inspired by the Arch Linux package by prozum
- Bump node version to 16 per upstream commit https://github.com/bitwarden/desktop/commit/5865f08b37d688ee057e82dd7acf90641b1978f5
